@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.1.15';
+our $VERSION = '0.1.16';
 
 1;
 
@@ -512,7 +512,7 @@ Examples:
 
 Use this command to run task box
 
-B<sparrow box run $path>
+B<sparrow box run $path [opts]>
 
 Where $path sets the file path to task box json file. A structure of the file:
 
@@ -559,6 +559,10 @@ Thus task box files should hold a list of sparrow tasks. Here is example:
     
     ]
 
+To suppress some extra message from this command use C<--mode quiet>:
+
+    $ sparrow box run /path/to/my/box/ --mode quiet
+
 
 =head1 Sparrow plugins
 
